@@ -5,6 +5,8 @@ except NameError:
     # Python 3
     basestring = unicode = str
 
+version = '1.0'
+
 def normalize_chain(chain):
     """
     Convenience method formatting attribute chain into iterables.
@@ -84,14 +86,3 @@ def walk(obj, chain):
     for attr in chain:
         obj = getattr(obj, attr)
         yield obj
-
-def attrgetter(chain, *args):
-    """
-    Returns a `get` function who's chain and default
-    has already been defined.
-
-    See `get` for behaviour
-    """
-    def _attrgetter(obj):
-        return get(obj, chain, *args)
-    return _attrgetter
